@@ -91,9 +91,12 @@ typedef enum {
 gboolean       gda_connection_supports (GdaConnection *cnc, GdaConnectionFeature feature);
 
 typedef enum {
+	GDA_CONNECTION_SCHEMA_AGGREGATES = GNOME_Database_Connection_SCHEMA_AGGREGATES,
+	GDA_CONNECTION_SCHEMA_FIELDS = GNOME_Database_Connection_SCHEMA_FIELDS,
 	GDA_CONNECTION_SCHEMA_INDEXES = GNOME_Database_Connection_SCHEMA_INDEXES,
 	GDA_CONNECTION_SCHEMA_PROCEDURES = GNOME_Database_Connection_SCHEMA_PROCEDURES,
 	GDA_CONNECTION_SCHEMA_TABLES = GNOME_Database_Connection_SCHEMA_TABLES,
+	GDA_CONNECTION_SCHEMA_TRIGGERS = GNOME_Database_Connection_SCHEMA_TRIGGERS,
 	GDA_CONNECTION_SCHEMA_TYPES = GNOME_Database_Connection_SCHEMA_TYPES,
 	GDA_CONNECTION_SCHEMA_VIEWS = GNOME_Database_Connection_SCHEMA_VIEWS
 } GdaConnectionSchema;
